@@ -63,6 +63,15 @@ while (time < $s) {
     $F->line({'x' => rand($XX), 'y' => rand($YY), 'xx' => rand($XX), 'yy' => rand($YY)});
 } ## end for (my $l = $F->{'Y_CLIP'...})
 
+print_it($F, 'Angle Line Test');
+$s = time + $factor;
+my $angle = 0;
+while (time < $s) {
+    $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
+    $F->angle_line({'x' => $center_x, 'y' => $center_y, 'radius' => $center_y, 'angle' => $angle++});
+    $angle = 0 if ($angle >= 360);
+} ## end for (my $l = $F->{'Y_CLIP'...})
+
 print_it($F, 'Box Test');
 $s = time + $factor;
 while (time < $s) {
